@@ -23,9 +23,10 @@
 #include <config.h>
 #endif
 
+#include "../testutilities.h"
 #include <libxml++/libxml++.h>
-
 #include <iostream>
+#include <cstdlib>
 
 void print_node(const xmlpp::Node* node, bool substitute_entities, unsigned int indentation = 0)
 {  
@@ -38,7 +39,7 @@ void print_node(const xmlpp::Node* node, bool substitute_entities, unsigned int
     const xmlpp::TextNode* nodeText = dynamic_cast<const xmlpp::TextNode*>(node);
     if (nodeText && !nodeText->is_white_space())
     {
-      std::cout << indent << "text = " << nodeText->get_content() << std::endl;
+      std::cout << indent << "text = " << CatchConvertError(nodeText->get_content()) << std::endl;
     }
   }
   else
@@ -47,9 +48,9 @@ void print_node(const xmlpp::Node* node, bool substitute_entities, unsigned int
     const xmlpp::EntityReference* nodeEntityReference = dynamic_cast<const xmlpp::EntityReference*>(node);
     if (nodeEntityReference)
     {
-      std::cout << indent << "entity reference name = " << nodeEntityReference->get_name() << std::endl;
-      std::cout << indent <<  "  resolved text = " << nodeEntityReference->get_resolved_text() << std::endl;
-      std::cout << indent <<  "  original text = " << nodeEntityReference->get_original_text() << std::endl;
+      std::cout << indent << "entity reference name = " << CatchConvertError(nodeEntityReference->get_name()) << std::endl;
+      std::cout << indent << "  resolved text = " << CatchConvertError(nodeEntityReference->get_resolved_text()) << std::endl;
+      std::cout << indent << "  original text = " << CatchConvertError(nodeEntityReference->get_original_text()) << std::endl;
     }
   } // end if (substitute_entities)
 
@@ -67,8 +68,8 @@ void print_node(const xmlpp::Node* node, bool substitute_entities, unsigned int
 
 int main(int argc, char* argv[])
 {
-  // Set the global C++ locale to the user-configured locale,
-  // so we can use std::cout with UTF-8, via Glib::ustring, without exceptions.
+  // Set the global C++ locale to the user-specified locale. Then we can
+  // hopefully use std::cout with UTF-8, via Glib::ustring, without exceptions.
   std::locale::global(std::locale(""));
 
   std::string filepath;
@@ -78,6 +79,7 @@ int main(int argc, char* argv[])
     filepath = "example.xml";
   
   // Parse first without, then with, entity substitution.
+  int return_code = EXIT_SUCCESS;
   bool substitute_entities = false;
   while (true)
   {
@@ -101,7 +103,8 @@ int main(int argc, char* argv[])
     }
     catch(const std::exception& ex)
     {
-      std::cout << "Exception caught: " << ex.what() << std::endl;
+      std::cerr << "Exception caught: " << ex.what() << std::endl;
+      return_code = EXIT_FAILURE;
     }
 
     if (substitute_entities) break;
@@ -109,6 +112,6 @@ int main(int argc, char* argv[])
     substitute_entities = true;
   }
 
-  return 0;
+  return return_code;
 }
 
